@@ -80,11 +80,12 @@ class ClientInfo(BaseModel):
     phone: Optional[str] = Field(description="Телефон")
     company_name: Optional[str] = Field(description="Название организации")
     position: Optional[str] = Field(description="Должность")
+    birthday: Optional[datetime_date] = Field(description="Дата рождения")
 
 
 class CreateClientRequest(ClientInfo):
     fio: str = Field(description="ФИО")
-    birthday: str = Field(description="Дата рождения")
+    birthday: datetime_date = Field(description="Дата рождения")
     country_id: int = Field(description="Id страны по справочнику")
 
 
@@ -94,6 +95,7 @@ class UpdateClientRequest(ClientInfo):
 
 class ClientResponse(ClientInfo):
     id: int = Field(description="Id гигтест клиента")
+    birthday: Optional[str] = Field(description="Дата рождения")
 
 
 # МЕДКНИЖКА
